pub async fn find_system_package(
dep: &Dependency,
pkgdep: &StringArray,
builddep: &StringArray,
) -> Result<Option<String>>Expand description
Finds the system package which provides a certain Python package.
pub async fn find_system_package(
dep: &Dependency,
pkgdep: &StringArray,
builddep: &StringArray,
) -> Result<Option<String>>Finds the system package which provides a certain Python package.